@@ -427,3 +427,140 @@
 #' 
 #' lambda3(ehrlen3mean)
 "lathyrus"
+
+#' Demographic Dataset of \emph{Cypripedium candidum} Population, in Vertical
+#' Format
+#' 
+#' A dataset containing the states and fates of \emph{Cypripedium candidum} 
+#' (white lady's slipper orchids), family Orchidaceae, from a population in 
+#' Illinois, USA, resulting from monitoring that occurred annually between 2004 
+#' and 2009. Same dataset as \code{cypdata}, but arranged in an ahistorical
+#' vertical format.
+#' 
+#' @docType data
+#' 
+#' @usage data(cypvert)
+#' 
+#' @format A data frame with 77 individuals, 322 rows, and 14 variables. Each
+#' row corresponds to a specific two-year transition for a specific individual.
+#' Variable codes are similar to those for \code{cypdata}, but use \code{.2} to
+#' identify occasion \emph{t} and \code{.3} to identify occasion \emph{t}+1.
+#' 
+#' \describe{
+#'   \item{plantid}{A numeric variable giving a unique number to each 
+#'   individual.}
+#'   \item{patch}{A variable refering to patch within the population.}
+#'   \item{X}{An X coordinate for the plant within the population.}
+#'   \item{Y}{A Y coordinate for the plant within the population.}
+#'   \item{censor}{A variable coding for whether the data point is valid. An
+#'   entry of 1 means that it is so.}
+#'   \item{year2}{Year in occasion \emph{t}.}
+#'   \item{Inf2.2}{Number of double inflorescences in occasion \emph{t}.}
+#'   \item{Inf.2}{Number of inflorescences in occasion \emph{t}.}
+#'   \item{Veg.2}{Number of stems without inflorescences in occasion \emph{t}.}
+#'   \item{Pod.2}{Number of fruits in occasion \emph{t}.}
+#'   \item{Inf2.3}{Number of double inflorescences in occasion \emph{t}+1.}
+#'   \item{Inf.3}{Number of inflorescences in occasion \emph{t}+1.}
+#'   \item{Veg.3}{Number of stems without inflorescences in occasion \emph{t}+1.}
+#'   \item{Pod.3}{Number of fruits in occasion \emph{t}+1.}
+#' }
+#' 
+#' @source Shefferson, R.P., R. Mizuta, and M.J. Hutchings. 2017. Predicting
+#' evolution in response to climate change: the example of sprouting probability
+#' in three dormancy-prone orchid species. \emph{Royal Society Open Science} 
+#' 4(1):160647.
+#' 
+#' @examples 
+#' data(cypvert)
+#' 
+#' sizevector <- c(0, 0, 0, 0, 0, 0, 1, 2.5, 4.5, 8, 17.5)
+#' stagevector <- c("SD", "P1", "P2", "P3", "SL", "D", "XSm", "Sm", "Md", "Lg",
+#'   "XLg")
+#' repvector <- c(0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1)
+#' obsvector <- c(0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1)
+#' matvector <- c(0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1)
+#' immvector <- c(0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0)
+#' propvector <- c(1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)
+#' indataset <- c(0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1)
+#' binvec <- c(0, 0, 0, 0, 0, 0.5, 0.5, 1, 1, 2.5, 7)
+#' 
+#' cypframe_raw <- sf_create(sizes = sizevector, stagenames = stagevector, 
+#'   repstatus = repvector, obsstatus = obsvector, matstatus = matvector, 
+#'   propstatus = propvector, immstatus = immvector, indataset = indataset,
+#'   binhalfwidth = binvec)
+#' 
+#' cypframe_raw
+#' 
+#' cypraw_v2 <- historicalize3(data = cypvert, patchidcol = "patch", 
+#'   individcol = "plantid", year2col = "year2", sizea2col = "Inf2.2", 
+#'   sizea3col = "Inf2.3", sizeb2col = "Inf.2", sizeb3col = "Inf.3", 
+#'   sizec2col = "Veg.2", sizec3col = "Veg.3", repstra2col = "Inf2.2", 
+#'   repstra3col = "Inf2.3", repstrb2col = "Inf.2", repstrb3col = "Inf.3", 
+#'   feca2col = "Pod.2", feca3col = "Pod.3", repstrrel = 2, 
+#'   stageassign = cypframe_raw, stagesize = "sizeadded", censorcol = "censor",
+#'   censor = FALSE, NAas0 = TRUE, NRasRep = TRUE, reduce = TRUE)
+#'   
+#' cypsupp2r <- supplemental(stage3 = c("SD", "P1", "P2", "P3", "SL", "D", 
+#'     "XSm", "Sm", "SD", "P1"),
+#'   stage2 = c("SD", "SD", "P1", "P2", "P3", "SL", "SL", "SL", "rep",
+#'     "rep"),
+#'   eststage3 = c(NA, NA, NA, NA, NA, "D", "XSm", "Sm", NA, NA),
+#'   eststage2 = c(NA, NA, NA, NA, NA, "XSm", "XSm", "XSm", NA, NA),
+#'   givenrate = c(0.10, 0.20, 0.20, 0.20, 0.25, NA, NA, NA, NA, NA),
+#'   multiplier = c(NA, NA, NA, NA, NA, NA, NA, NA, 0.5, 0.5),
+#'   type =c(1, 1, 1, 1, 1, 1, 1, 1, 3, 3),
+#'   stageframe = cypframe_raw, historical = FALSE)
+#' 
+#' cypmatrix2r <- rlefko2(data = cypraw_v2, stageframe = cypframe_raw, 
+#'   year = "all", patch = "all", stages = c("stage3", "stage2"),
+#'   size = c("size3added", "size2added"), supplement = cypsupp2r,
+#'   yearcol = "year2", patchcol = "patchid", indivcol = "individ")
+#'   
+#' cypmatrix2r$A[[intersect(which(cypmatrix2r$labels$patch == "A"), 
+#'   which(cypmatrix2r$labels$year2 == 2004))]]
+#' 
+#' lambda3(cypmatrix2r)
+"cypvert"
+
+#' Matrix Set of \emph{Anthyllis vulneraria} Populations in Belgium
+#' 
+#' A \code{lefkoMat} object containing projection matrices developed from
+#' demographic data gathered on nine \emph{Anthyllis vulneraria} populations
+#' from 2003 to 2006 in southwestern Belgium. These matrices were originally
+#' published in Davison et al. (2010; Journal of Eccology 98(2): 255-267).
+#' 
+#' @docType data
+#' 
+#' @usage data(anthyllis)
+#' 
+#' @format A \code{lefkoMat} object holding 27 matrices. The structure of the
+#' object is as below:
+#' 
+#' \describe{
+#'   \item{A}{The 27 A matrices.}
+#'   \item{U}{The 27 survival-transition matrices used to develop the A
+#'   matrices.}
+#'   \item{F}{The 27 fecundity matrices used to develop the A matrices.}
+#'   \item{hstages}{Not used, so set to \code{NA}.}
+#'   \item{agestages}{Not used, so set to \code{NA}.}
+#'   \item{ahstages}{The edited stageframe describing the life history of the
+#'   study organism as interpreted in the original demographic study.}
+#'   \item{labels}{The order of the matrices, where each population is treated
+#'   as a separate patch and each matrix corresponds to a different combination
+#'   of population and year in time \emph{t}.}
+#'   \item{matrixqc}{A vector of integers used in the quality control section of
+#'   \code{lefkoMat} summary statements.}
+#' }
+#' 
+#' @source Davison, R. et al. 2010. Demographic effects of extreme weather
+#' events on a short-lived calcareous grassland species: stochastic life table
+#' response experiments. \emph{Journal of Ecology} 98(2):255-267.
+#' 
+#' @examples
+#' data(anthyllis)
+#' 
+#' summary(anthyllis)
+#' 
+#' lambda3(anthyllis)
+"anthyllis"
+
